@@ -1,6 +1,6 @@
-package Pcore::DBD v0.3.5;
+package Pcore::DBD v0.4.0;
 
-use Pcore -role;
+use Pcore -dist, -role;
 use Pcore::Util::Text qw[escape_scalar];
 use DBI;
 
